function [ out, parsnew, errmsg ] = CLS2FFCFalgo( pars, covar, properr )
%CLS2FFCF_ALGO Calculate FFCF from CLS parameters using neural network
%algorithm
%{
% inputs: pars in following order:
    pars(1) = A_inf (CLS offset)
    pars(2) = A_1
    pars(3) = tau_1 (ps)
    pars(4) = A_2
    pars(5) = tau_2 (ps)
    pars(6) = A_3
    pars(7) = tau_3 (ps)
    pars(8) = fwhm  (cm^-1)

    covar: Covariance matrix for input 

  out: first row: Delta and Gamma
       second row: std err for Delta and Gamma
%}

        
        
        errmsg = '';
        %Calculate FFCF Deltas and errors using Neural Networks
        [Delta(1), DeltaErr(1)] = calc_value_w_error(@calcDelta1, pars, covar);
        [Delta(2), DeltaErr(2)] = calc_value_w_error(@calcDelta2, pars, covar);
        [Delta(3), DeltaErr(3)] = calc_value_w_error(@calcDelta3, pars, covar);
        [Delta(4), DeltaErr(4)] = calc_value_w_error(@calcDelta4, pars, covar);
        disp('Calculated Delta')
        %Check that the calculated Deltas and input taus correspond to a
        %physical FFCF
        p = 3;
        p_stddev = sqrt(covar(p,p));
        inc = 0.1;
        parsnew = pars;
        if any(Delta(1:3) > 0)
            
            tau = [pars(3) pars(5) pars(7)];
            fwhm = pars(8);
            
            x = 0;
            cnt = 0;
            simFWHM = calcFWHMfromFFCF(Delta, tau, 0);
            while simFWHM > fwhm %If the calculated Deltas do not match physical FFCF, slowly increase tau_1 until it does.
                if properr ~= 3
                    %break if not using covariance method
                    error('Calculated linewidth exceeds experimental FWHM. Use covariance matrix to attempt correction.');
                end
                
                cnt = cnt +1;
                if cnt>50
                    %break after attempting 5 std. dev.
                    error('Calculated linewidth exceeds experimental FWHM. Correction attempt failed. Check input values.');
                end
                x = x + inc;
                parsnew =  pars + (x/p_stddev)*covar(:,p); %Generate new pars from covariance matrix.
                
                [Delta(1), DeltaErr(1)] = calc_value_w_error(@calcDelta1, parsnew, covar);
                [Delta(2), DeltaErr(2)] = calc_value_w_error(@calcDelta2, parsnew, covar);
                [Delta(3), DeltaErr(3)] = calc_value_w_error(@calcDelta3, parsnew, covar);
                [Delta(4), DeltaErr(4)] = calc_value_w_error(@calcDelta4, parsnew, covar);
                tau = [parsnew(3) parsnew(5) parsnew(7)];
                
                simFWHM = calcFWHMfromFFCF(Delta, tau, 0);
                errmsg = ['Increased tau_1 by ' num2str(x) ' std. dev to obtain experimental linewidth. Check "parsnew" output for new time constants.'];
                
            end
        end
        pars = parsnew;
        %Calculate Gamma
        [Gamma, GammaErr] = calc_value_w_error(@calcGammaScale, pars, covar);

        %output
        out = [Delta Gamma; DeltaErr GammaErr]';
end

