function [ S1, omega ] = Gen_1D_Spec( R1, t1, varargin )
% Fourier transform the linear response function R1 to get the absorption
% lineshape

c = 2.99792458e-2; % Speed of light in cm/ps
if ~isempty(varargin)
    pad = varargin{1}; % Number of times to zero pad beyond the next power of 2 of the length
else
    pad = 2; 
end

% Number of time points for fft
nfft_t1 = 2^(nextpow2(length(t1)) + pad); 

% Point spacing
t1space = t1(2)-t1(1);

% Frequency spacing in ps^-1 units
fspace_1_invps = 1/(t1space*nfft_t1);
% Convert to cm^-1
fspace_1 = fspace_1_invps/c;
% Generate the zero-centered axes in wavenumbers
omega = fspace_1*((-nfft_t1/2):1:(nfft_t1/2 - 1));

% Prepare to do the FFT
R1_half = R1;
R1_half(1) = 1/2*R1_half(1);

S1 = fftshift(fft(R1_half, nfft_t1, 1));
end

