function [ Delta1, nnvar] = calcDelta1( A, tau, fwhm, varargin )
%Calculate Delta1 using neural network from CLS parameters (A, tau [ps]) and
%fwhm (cm-1) of absorption spectrum.

%Delta1: output of NN in (cm-1)
%nnvar: Neural network variance from calculation

    if (A(1) > 0) %If A(1) is nonzero
        c = 2.99792458e-2; %speed of light in cm/ps
        taufull = [tau, 1e6];
        log_s = log10(fwhm*2*pi*c*taufull.*sqrt(A/sum(A)));                 %calculate rescaled CLS parameter s

        if A(2) <= 0 %If A(2) is zero, use substitute log_s(2) value
            log_s(2) = 6.7;
        end
        data_in = [A(1), log_s(1), A(2), log_s(2) A(3)+A(4)]';              %Set up NN input
        
        sigma1 = 10^logSigma1ANN(data_in);                             %Calculate rescaled FFCF parameter sigma1 from NN
        Delta1 = sigma1/(2*pi*c*taufull(1));                                %Calculate Delta1 from sigma1
    else %If A(1) is zero
        Delta1 = 0;
    end
    nnvar = (Delta1 * log(10) * 0.01452)^2; %Calculate variance from error propagation
end