function [ Delta3, nnvar ] = calcDelta3( A, tau, fwhm, varargin )
%Calculate Delta3 using neural network from CLS parameters (A, tau [ps]) and
%fwhm (cm-1) of absorption spectrum.

%Delta3: output of NN in (cm-1)
%nnvar: Neural network variance from calculation
    if (A(3) > 0) %If A(3) is nonzero
        c = 2.99792458e-2; %speed of light in cm/ps
        taufull = [tau, 1e6];
        log_s = log10(fwhm*2*pi*c*taufull.*sqrt(A/sum(A)));                    %calculate rescaled CLS parameter s

        data_in = [A(1)+A(2), 0.5*(log_s(1)+log_s(2)), A(3), log_s(3), A(4)]'; %Set up NN input
        sigma3 = 10^logSigma2ANN(data_in);                                    %Calculate rescaled FFCF parameter sigma3 from NN
        Delta3 = sigma3/(2*pi*c*taufull(3));                                   %Calculate Delta3 from sigma3
    else %If A(3) is zero
        Delta3 = 0;
    end
    
    nnvar = (Delta3 * log(10) * 0.01173)^2; %Calculate variance from error propagation
end