function [ Delta4, nnvar ] = calcDelta4( A, tau, fwhm, varargin )
%Calculate Delta4 (Delta_Inf) using neural network from CLS parameters (A, tau [ps]) and
%fwhm (cm-1) of absorption spectrum.

%Delta4: output of NN in (cm-1)
%nnvar: Neural network variance from calculation
    if (A(4) > 0) %If A(4) is nonzero
        c = 2.99792458e-2; %speed of light in cm/ps
        taufull = [tau, 1e6];
        log_s = log10(fwhm*2*pi*c*taufull.*sqrt(A/sum(A)));                    %calculate rescaled CLS parameter s
        if A(1) == 0 %If A(1) is zero, use substitute log_s(1) value
            log_s(1) = 4;
        end

        if (A(3) > 0) %If A(3) is nonzero, use substitute log_s(2) value
            log_s2_eff = 0.5*(log_s(2)+log_s(3));
        else
            log_s2_eff = log_s(2);
        end
        
        if A(2) == 0 %If A(2) is nonzero, use substitute log_s(2) value
            log_s2_eff = 6.7;
        end
        data_in = [A(1), log_s(1), A(2)+A(3), log_s2_eff, A(4)]'; %Set up NN input
        
        sigmaInf = SigmaInfANN(data_in); %Calculate rescaled FFCF parameter sigma_inf from NN
        Delta4 = sqrt(sigmaInf*fwhm^2)/2.355;   %Calculate Delta4 (Delta_Inf) from sigma_inf
        nnvar = (Delta4*0.5*0.00138/sigmaInf)^2; %Calculate variance from error propagation
    else %If A(4) is zero
        Delta4 = 0;
        nnvar = 0;
    end
    
end