function [ Gamma, nnvar, Delta ] = calcGammaScale( A, tau, fwhm, varargin )
%{
Calculate Gamma from Deltas and taus which are calculated using neural networks from
CLS parameters (A, tau [ps]) and the linear spectrum absorption fwhm (cm^-1).
varargin{1} = 1 if NN error calculation is desired

%Gamma: output of calculation in (cm-1)
%nnvar: variance from neural network calculation
%}

%Takes advantage of rescaling to get better accuracy in Gamma calcuation


    fwhmscale = 20; %scaled FWHM choice

    tauscale = tau*fwhm/fwhmscale; %Scale tau to conserve CLS s parameters

    %Calculate scaled Deltas and their variances
    [Delta(1), DeltaVar(1)] = calcDelta1(A,tauscale,fwhmscale);
    [Delta(2), DeltaVar(2)] = calcDelta2(A,tauscale,fwhmscale);
    [Delta(3), DeltaVar(3)] = calcDelta3(A,tauscale,fwhmscale);
    [Delta(4), DeltaVar(4)] = calcDelta4(A,tauscale,fwhmscale);
    
    %Minimization function to calculate gamma based on scaled FWHM.
    f = @(G) (calcFWHMfromFFCF(Delta, tauscale, G) - fwhmscale)^2;
    Gamma_uns = fminsearch(f,fwhmscale); %Minimize function to get Gamma
    Gamma = Gamma_uns*fwhm/fwhmscale; %Undo scaling to get actual Gamma
    %Gamma = fminunc(f,fwhm);
    
    
    %Set up gradient calculations
    nnvar = 0;
    h = .02;
    newDelta = repmat(Delta',1,4) + diag(h*Delta);
    deriv = zeros(1,length(Delta));
    
    %Check if gradient calculation should be performed
    doErrCalc = 0;
    if nargin > 3
        doErrCalc = varargin{1};
    end
    
    if doErrCalc
        for i = 1:4
            if A(i) > 0 %Calculate gradient for each nonzero Delta
                f = @(G) (calcFWHMfromFFCF(newDelta(:,i)', tauscale, G) - fwhmscale)^2;
                Gamma2 = fminsearch(f,fwhmscale);           %Get perturbed Gamma
                deriv(i) = (Gamma2-Gamma_uns)/(h*Delta(i)); %Calculate gradient
                nnvar = nnvar + DeltaVar(i)*deriv(i)^2;     %Update total variance
            end
        end
    end
    nnvar = nnvar * (fwhm/fwhmscale)^2; %Rescale variance to get true variance
    
end